<?php
session_start();
require_once '../../config.php';

if (!isset($_SESSION['user'])) {
    header("Location: /");
    exit;
}

if ($_SESSION['user']['id_role'] != 2) {
    header("Location: /pages/user/");
    exit;
}

$user = $_SESSION['user'];

if (isset($_POST['update_status'])) {
    $id_application = $_POST['id_application'];
    $id_status = $_POST['id_status'];
    $status_info = $_POST['status_info'] ?? '';
    
    $stmt = $db->prepare("UPDATE application SET id_status = ?, status_info = ? WHERE id_application = ?");
    $stmt->execute([$id_status, $status_info, $id_application]);
    
    header("Location: index.php");
    exit;
}

$stmt = $db->prepare("SELECT a.*, s.status, s.code as status_code, p.name as pay_name, 
                      u.name as user_name, u.surname as user_surname, u.patronymic as user_patronymic, u.phone as user_phone
                      FROM application a 
                      JOIN status s ON a.id_status = s.id_status 
                      JOIN pay p ON a.id_pay = p.id_pay 
                      JOIN user u ON a.id_user = u.id_user
                      ORDER BY a.date DESC, a.time DESC");
$stmt->execute();
$allApplications = $stmt->fetchAll(PDO::FETCH_ASSOC);

$applications = [
    'new' => [],
    'process' => [],
    'confirmed' => [],
    'canceled' => []
];

foreach ($allApplications as $app) {
    $applications[$app['status_code']][] = $app;
}

$counts = [
    'new' => count($applications['new']),
    'process' => count($applications['process']),
    'confirmed' => count($applications['confirmed']),
    'canceled' => count($applications['canceled']),
    'total' => count($allApplications)
];

$stmt = $db->prepare("SELECT * FROM status");
$stmt->execute();
$statuses = $stmt->fetchAll(PDO::FETCH_ASSOC);

$pageTitle = 'Панель администратора';
require_once '../../includes/header.php';
?>

<div class="container">
    <div class="row">
        <div class="col-12">
            <ul class="nav nav-tabs mb-4" id="applicationTabs" role="tablist">
                <li class="nav-item" role="presentation">
                    <button class="nav-link active" id="new-tab" data-bs-toggle="tab" data-bs-target="#new" type="button" role="tab" aria-controls="new" aria-selected="true">
                        Новые <span class="badge bg-primary ms-1"><?= $counts['new'] ?></span>
                    </button>
                </li>
                <li class="nav-item" role="presentation">
                    <button class="nav-link" id="process-tab" data-bs-toggle="tab" data-bs-target="#process" type="button" role="tab" aria-controls="process" aria-selected="false">
                        В работе <span class="badge bg-warning ms-1"><?= $counts['process'] ?></span>
                    </button>
                </li>
                <li class="nav-item" role="presentation">
                    <button class="nav-link" id="confirmed-tab" data-bs-toggle="tab" data-bs-target="#confirmed" type="button" role="tab" aria-controls="confirmed" aria-selected="false">
                        Выполнено <span class="badge bg-success ms-1"><?= $counts['confirmed'] ?></span>
                    </button>
                </li>
                <li class="nav-item" role="presentation">
                    <button class="nav-link" id="canceled-tab" data-bs-toggle="tab" data-bs-target="#canceled" type="button" role="tab" aria-controls="canceled" aria-selected="false">
                        Отменено <span class="badge bg-danger ms-1"><?= $counts['canceled'] ?></span>
                    </button>
                </li>
                <li class="nav-item" role="presentation">
                    <button class="nav-link" id="all-tab" data-bs-toggle="tab" data-bs-target="#all" type="button" role="tab" aria-controls="all" aria-selected="false">
                        Все заказы <span class="badge bg-secondary ms-1"><?= $counts['total'] ?></span>
                    </button>
                </li>
            </ul>
            
            <div class="tab-content" id="applicationTabsContent">
                <div class="tab-pane fade show active" id="new" role="tabpanel" aria-labelledby="new-tab">
                    <?php if (count($applications['new']) > 0): ?>
                        <?php foreach ($applications['new'] as $app): ?>
                            <?php include '../../templates/application_card.php'; ?>
                        <?php endforeach; ?>
                    <?php else: ?>
                        <div class="alert alert-info">Нет новых заказов</div>
                    <?php endif; ?>
                </div>
                
                <div class="tab-pane fade" id="process" role="tabpanel" aria-labelledby="process-tab">
                    <?php if (count($applications['process']) > 0): ?>
                        <?php foreach ($applications['process'] as $app): ?>
                            <?php include '../../templates/application_card.php'; ?>
                        <?php endforeach; ?>
                    <?php else: ?>
                        <div class="alert alert-info">Нет заказов в работе</div>
                    <?php endif; ?>
                </div>
                
                <div class="tab-pane fade" id="confirmed" role="tabpanel" aria-labelledby="confirmed-tab">
                    <?php if (count($applications['confirmed']) > 0): ?>
                        <?php foreach ($applications['confirmed'] as $app): ?>
                            <?php include '../../templates/application_card.php'; ?>
                        <?php endforeach; ?>
                    <?php else: ?>
                        <div class="alert alert-info">Нет выполненных заказов</div>
                    <?php endif; ?>
                </div>
                
                <div class="tab-pane fade" id="canceled" role="tabpanel" aria-labelledby="canceled-tab">
                    <?php if (count($applications['canceled']) > 0): ?>
                        <?php foreach ($applications['canceled'] as $app): ?>
                            <?php include '../../templates/application_card.php'; ?>
                        <?php endforeach; ?>
                    <?php else: ?>
                        <div class="alert alert-info">Нет отмененных заказов</div>
                    <?php endif; ?>
                </div>
                
                <div class="tab-pane fade" id="all" role="tabpanel" aria-labelledby="all-tab">
                    <?php if (count($allApplications) > 0): ?>
                        <?php foreach ($allApplications as $app): ?>
                            <?php include '../../templates/application_card.php'; ?>
                        <?php endforeach; ?>
                    <?php else: ?>
                        <div class="alert alert-info">Заказов пока нет</div>
                    <?php endif; ?>
                </div>
            </div>
        </div>
    </div>
</div>

<script>
    document.querySelectorAll('.status-select').forEach(select => {
        select.addEventListener('change', function() {
            const appId = this.getAttribute('data-app-id');
            const reasonContainer = document.getElementById(`reason_container_${appId}`);
            const statusInfoInput = document.getElementById(`status_info_${appId}`);
            
            if (this.value == '2') {
                reasonContainer.style.display = 'block';
                statusInfoInput.setAttribute('required', 'required');
            } else {
                reasonContainer.style.display = 'none';
                statusInfoInput.removeAttribute('required');
            }
        });

        select.dispatchEvent(new Event('change'));
    });
</script>

<?php
require_once '../../includes/footer.php';
?>