<?php
session_start();
require_once '../../config.php';

if (!isset($_SESSION['user'])) {
    header("Location: /");
    exit;
}

if ($_SESSION['user']['id_role'] == 2) {
    header("Location: /pages/admin/");
    exit;
}

$user = $_SESSION['user'];

$stmt = $db->prepare("SELECT * FROM product");
$stmt->execute();
$products = $stmt->fetchAll(PDO::FETCH_ASSOC);

$stmt = $db->prepare("SELECT * FROM pay");
$stmt->execute();
$payments = $stmt->fetchAll(PDO::FETCH_ASSOC);

if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    $products_selected = $_POST['products'] ?? [];
    $quantities = $_POST['quantities'] ?? [];
    $id_pay = $_POST['id_pay'];
    $description = $_POST['description'];
    $date = $_POST['date'];
    $time = $_POST['time'];
    $phone = $_POST['phone'];
    $address = $_POST['address'];

    $db->beginTransaction();
    try {
        $stmt = $db->prepare("INSERT INTO application (id_user, id_pay, id_status, status_info, description, date, time, phone, address) 
                              VALUES (?, ?, 1, '', ?, ?, ?, ?, ?)");
        $stmt->execute([
            $user['id_user'],
            $id_pay,
            $description,
            $date,
            $time,
            $phone,
            $address
        ]);
        $id_application = $db->lastInsertId();

        foreach ($products_selected as $index => $id_product) {
            if (isset($quantities[$index]) && $quantities[$index] > 0) {
                $stmt = $db->prepare("INSERT INTO application_product (id_application, id_product, quantity) VALUES (?, ?, ?)");
                $stmt->execute([$id_application, $id_product, $quantities[$index]]);
            }
        }

        $db->commit();
        header("Location: my_orders.php");
        exit;
    } catch (Exception $e) {
        $db->rollBack();
        echo "Ошибка: " . $e->getMessage();
    }
}

$pageTitle = 'Заказ товаров';
require_once '../../includes/header.php';
?>

<div class="container">
    <div class="row">
        <div class="col-md-12">
            <div class="card">
                <div class="card-header">
                    <h5 class="mb-0">Создать заказ</h5>
                </div>
                <div class="card-body">
                    <form method="POST">
                        <div class="mb-3">
                            <label class="form-label">Товары</label>
                            <?php foreach ($products as $index => $product): ?>
                                <div class="row mb-2">
                                    <div class="col-md-6">
                                        <div class="form-check">
                                            <input type="checkbox" class="form-check-input" name="products[]" 
                                                   value="<?= $product['id_product'] ?>" id="product_<?= $product['id_product'] ?>">
                                            <label class="form-check-label" for="product_<?= $product['id_product'] ?>">
                                                <?= $product['name'] ?>
                                            </label>
                                        </div>
                                    </div>
                                    <div class="col-md-6">
                                        <input type="number" class="form-control" name="quantities[]" min="0" value="0" 
                                               placeholder="Количество">
                                    </div>
                                </div>
                            <?php endforeach; ?>
                        </div>

                        <div class="mb-3">
                            <label for="description" class="form-label">Описание</label>
                            <textarea class="form-control" id="description" name="description" rows="3"></textarea>
                        </div>

                        <div class="mb-3">
                            <label for="address" class="form-label">Адрес</label>
                            <input type="text" class="form-control" id="address" name="address" required>
                        </div>

                        <div class="mb-3">
                            <label for="phone" class="form-label">Телефон</label>
                            <input type="tel" class="form-control" id="phone" name="phone" value="<?= $user['phone'] ?>" required>
                        </div>

                        <div class="row">
                            <div class="col-md-6 mb-3">
                                <label for="date" class="form-label">Дата</label>
                                <input type="date" class="form-control" id="date" name="date" required>
                            </div>
                            <div class="col-md-6 mb-3">
                                <label for="time" class="form-label">Время</label>
                                <input type="time" class="form-control" id="time" name="time" required>
                            </div>
                        </div>

                        <div class="mb-3">
                            <label for="id_pay" class="form-label">Способ оплаты</label>
                            <select class="form-select" id="id_pay" name="id_pay" required>
                                <?php foreach ($payments as $payment): ?>
                                    <option value="<?= $payment['id_pay'] ?>"><?= $payment['name'] ?></option>
                                <?php endforeach; ?>
                            </select>
                        </div>

                        <div class="d-grid">
                            <button type="submit" class="btn btn-primary">Отправить заказ</button>
                        </div>
                    </form>
                </div>
            </div>
        </div>
    </div>
</div>

<script>
    const dateInput = document.getElementById('date');
    const today = new Date().toISOString().split('T')[0];
    dateInput.setAttribute('min', today);
    dateInput.value = today;

    document.getElementById('phone').addEventListener('input', function (e) {
        let x = e.target.value.replace(/\D/g, '').match(/(\d{0,1})(\d{0,3})(\d{0,3})(\d{0,2})(\d{0,2})/);
        e.target.value = !x[2] ? x[1] : '+' + x[1] + '(' + x[2] + ')-' + (x[3] ? x[3] + '-' : '') + (x[4] ? x[4] + '-' : '') + x[5];
    });
</script>

<?php
require_once '../../includes/footer.php';
?>