<?php
$stmt = $db->prepare("SELECT p.name, ap.quantity 
                      FROM application_product ap 
                      JOIN product p ON ap.id_product = p.id_product 
                      WHERE ap.id_application = ?");
$stmt->execute([$app['id_application']]);
$products = $stmt->fetchAll(PDO::FETCH_ASSOC);

// Determine client information with robust fallbacks
$client_surname = isset($app['user_surname']) ? $app['user_surname'] : (isset($_SESSION['user']['surname']) ? $_SESSION['user']['surname'] : 'Неизвестный');
$client_name = isset($app['user_name']) ? $app['user_name'] : (isset($_SESSION['user']['name']) ? $_SESSION['user']['name'] : 'Клиент');
$client_patronymic = isset($app['user_patronymic']) ? $app['user_patronymic'] : (isset($_SESSION['user']['patronymic']) ? $_SESSION['user']['patronymic'] : '');
$client_phone = isset($app['user_phone']) ? $app['user_phone'] : (isset($_SESSION['user']['phone']) ? $_SESSION['user']['phone'] : 'Не указан');
?>

<div class="card mb-3">
    <div class="card-body">
        <div class="d-flex justify-content-between align-items-center mb-2">
            <h5 class="card-title mb-0">Заказ #<?= $app['id_application'] ?></h5>
            <span class="badge status-badge status-<?= $app['status_code'] ?>"><?= $app['status'] ?></span>
        </div>
        
        <div class="row">
            <div class="col-md-6">
                <p class="mb-1"><strong>Клиент:</strong> <?= htmlspecialchars($client_surname . ' ' . $client_name . ' ' . $client_patronymic) ?></p>
                <p class="mb-1"><strong>Телефон клиента:</strong> <?= htmlspecialchars($client_phone) ?></p>
                <p class="mb-1"><strong>Адрес:</strong> <?= htmlspecialchars($app['address']) ?></p>
                <p class="mb-1"><strong>Контактный телефон:</strong> <?= htmlspecialchars($app['phone']) ?></p>
            </div>
            <div class="col-md-6">
                <p class="mb-1"><strong>Дата:</strong> <?= date('d.m.Y', strtotime($app['date'])) ?></p>
                <p class="mb-1"><strong>Время:</strong> <?= date('H:i', strtotime($app['time'])) ?></p>
                <p class="mb-1"><strong>Оплата:</strong> <?= htmlspecialchars($app['pay_name']) ?></p>
                <p class="mb-1"><strong>ID заказа:</strong> <?= $app['id_application'] ?></p>
            </div>
        </div>
        
        <div class="mt-2">
            <p class="mb-1"><strong>Товары:</strong></p>
            <ul class="list-group list-group-flush">
                <?php foreach ($products as $product): ?>
                    <li class="list-group-item"><?= htmlspecialchars($product['name']) ?> (Количество: <?= $product['quantity'] ?>)</li>
                <?php endforeach; ?>
            </ul>
        </div>
        
        <p class="mt-2"><strong>Описание:</strong> <?= htmlspecialchars($app['description'] ?: 'Нет описания') ?></p>
        
        <?php if (!empty($app['status_info']) && $app['status_code'] == 'canceled'): ?>
            <div class="alert alert-danger mt-2 mb-0">
                <strong>Причина отмены:</strong> <?= htmlspecialchars($app['status_info']) ?>
            </div>
        <?php endif; ?>
        
        <?php if (isset($_SESSION['user']['id_role']) && $_SESSION['user']['id_role'] == 2): ?>
            <form method="POST" action="/pages/admin/index.php">
                <input type="hidden" name="id_application" value="<?= $app['id_application'] ?>">
                <div class="mb-3">
                    <label for="id_status_<?= $app['id_application'] ?>" class="form-label">Изменить статус</label>
                    <select class="form-select status-select" id="id_status_<?= $app['id_application'] ?>" name="id_status" data-app-id="<?= $app['id_application'] ?>">
                        <?php foreach ($statuses as $status): ?>
                            <option value="<?= $status['id_status'] ?>" <?= $app['id_status'] == $status['id_status'] ? 'selected' : '' ?>>
                                <?= $status['status'] ?>
                            </option>
                        <?php endforeach; ?>
                    </select>
                </div>
                
                <div id="reason_container_<?= $app['id_application'] ?>" style="display: none;">
                    <label for="status_info_<?= $app['id_application'] ?>" class="form-label">Причина отмены</label>
                    <textarea class="form-control" id="status_info_<?= $app['id_application'] ?>" name="status_info"></textarea>
                </div>
                
                <button type="submit" name="update_status" class="btn btn-primary mt-2">Сохранить</button>
            </form>
        <?php endif; ?>
    </div>
</div>